# Tests for DB version
# AM_CHECK_DB checks for a minimum version of db2 from glibc
# AM_CHECK_DB2 checks for a minimum version of db2 as a separate lib
# Derived from acinclude.m4 in E

dnl AM_CHECK_DB([MINIMUM-VERSION, [ACTION-IF-FOUND [, ACTION-IF-NOT-FOUND]]])
dnl Test for DB, and define DB_CFLAGS and DB_LIBS
dnl
AC_DEFUN(AM_CHECK_DB,
[dnl
dnl Get the cflags and libraries here some day

  min_db_version=ifelse([$1], ,2.4.14,$1)
  AC_MSG_CHECKING(for glibc DB version >= $min_db_version)
  no_db=""

  if test "$DB_CONFIG" = "no" ; then
    no_db=yes
  else
    DB_CFLAGS=""
    DB_LIBS="-ldb"
    ac_save_CFLAGS="$CFLAGS"
    ac_save_LIBS="$LIBS"
    CFLAGS="$CFLAGS $DB_CFLAGS"
    LIBS="$LIBS $DB_LIBS"

rm -f conf.dbtest
AC_TRY_RUN([
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <db.h>

char*
my_strdup (char *str)
{
  char *new_str;

  if (str) {
    new_str = malloc ((strlen (str) + 1) * sizeof(char));
    strcpy (new_str, str);
  } else {
    new_str = NULL;
  }

  return new_str;
}

int main ()
{
  int major, minor, micro;
  int lmajor, lminor, lmicro;
  char *tmp_version;

  system ("touch conf.dbtest");

  /* HP/UX 9 (%@#!) writes to sscanf strings */
  tmp_version = my_strdup("$min_db_version");
  if (sscanf(tmp_version, "%d.%d.%d", &major, &minor, &micro) != 3) {
     printf("%s, bad version string\n", "$min_db_version");
     exit(1);
  }

  db_version(&lmajor,&lminor,&lmicro);

  if ((lmajor > major) ||
      ((lmajor == major) && (lminor > minor)) ||
      ((lmajor == major) && (lminor == minor) && (lmicro >= micro)))
  {
    return 0;
  } else {
      printf("\n*** 'db_version' returned %d.%d.%d, but the minimum version\n", lmajor, lminor, lmicro);
      printf("*** of DB required is %d.%d.%d. If db_version is correct, then it is\n", major, minor, micro);
      printf("*** best to upgrade glibc to the version with the right db version.\n");
      return 1;
  }
}

],, no_db=yes,[echo $ac_n "cross compiling; assumed OK... $ac_c"])
     CFLAGS="$ac_save_CFLAGS"
     LIBS="$ac_save_LIBS"
  fi
  if test "x$no_db" = x ; then
     AC_MSG_RESULT(yes)
     ifelse([$2], , :, [$2])
  else
     AC_MSG_RESULT(no)
     if test "$DB_CONFIG" = "no" ; then
       echo "*** The db_version function could not be found in the DB library."
     else
       if test -f conf.dbtest ; then
        :
       else
          echo "*** Could not run DB test program, checking why..."
          CFLAGS="$CFLAGS $DB_CFLAGS"
          LIBS="$LIBS $DB_LIBS"
          AC_TRY_LINK([
#include <stdio.h>
#include <db.h>
],      [ return 0; ],
        [ echo "*** The test program compiled, but did not run. This usually means"
          echo "*** that the run-time linker is not finding DB or finding the wrong"
          echo "*** version of DB. If it is not finding DB, you'll need to set your"
          echo "*** LD_LIBRARY_PATH environment variable, or edit /etc/ld.so.conf to point"
          echo "*** to the installed location. Also, make sure you have run ldconfig if that"
          echo "*** is required on your system"],
        [ echo "*** The test program failed to compile or link. See the file config.log for the"
          echo "*** exact error that occured." ])

          CFLAGS="$ac_save_CFLAGS"
          LIBS="$ac_save_LIBS"
       fi
     fi
     DB_CFLAGS=""
     DB_LIBS=""
     ifelse([$3], , :, [$3])
  fi
  AC_SUBST(DB_CFLAGS)
  AC_SUBST(DB_LIBS)
  rm -f conf.dbtest
])

dnl AM_CHECK_DB2([MINIMUM-VERSION, [ACTION-IF-FOUND [, ACTION-IF-NOT-FOUND]]])
dnl Test for DB2, and define DB2_CFLAGS and DB2_LIBS
dnl
AC_DEFUN(AM_CHECK_DB2,
[dnl
dnl Get the cflags and libraries here some day

  min_db2_version=ifelse([$1], ,2.4.14,$1)
  AC_MSG_CHECKING(for DB2 version >= $min_db2_version)
  no_db2=""

  if test "$DB2_CONFIG" = "no" ; then
    no_db2=yes
  else
    DB2_CFLAGS=""
    DB2_LIBS="-ldb2"
    ac_save_CFLAGS="$CFLAGS"
    ac_save_LIBS="$LIBS"
    CFLAGS="$CFLAGS $DB2_CFLAGS"
    LIBS="$LIBS $DB2_LIBS"

rm -f conf.db2test
AC_TRY_RUN([
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <db2/db.h>

char*
my_strdup (char *str)
{
  char *new_str;

  if (str) {
    new_str = malloc ((strlen (str) + 1) * sizeof(char));
    strcpy (new_str, str);
  } else {
    new_str = NULL;
  }

  return new_str;
}

int main ()
{
  int major, minor, micro;
  int lmajor, lminor, lmicro;
  char *tmp_version;

  system ("touch conf.db2test");

  /* HP/UX 9 (%@#!) writes to sscanf strings */
  tmp_version = my_strdup("$min_db2_version");
  if (sscanf(tmp_version, "%d.%d.%d", &major, &minor, &micro) != 3) {
     printf("%s, bad version string\n", "$min_db2_version");
     exit(1);
  }

  db_version(&lmajor,&lminor,&lmicro);

  if ((lmajor > major) ||
      ((lmajor == major) && (lminor > minor)) ||
      ((lmajor == major) && (lminor == minor) && (lmicro >= micro)))
  {
    return 0;
  } else {
      printf("\n*** 'db_version' returned %d.%d.%d, but the minimum version\n", lmajor, lminor, lmicro);
      printf("*** of DB2 required is %d.%d.%d. If db_version is correct, then it is\n", major, minor, micro);
      printf("*** best to upgrade to the required version.\n");
      return 1;
  }
}

],, no_db2=yes,[echo $ac_n "cross compiling; assumed OK... $ac_c"])
     CFLAGS="$ac_save_CFLAGS"
     LIBS="$ac_save_LIBS"
  fi
  if test "x$no_db2" = x ; then
     AC_MSG_RESULT(yes)
     ifelse([$2], , :, [$2])
  else
     AC_MSG_RESULT(no)
     if test "$DB2_CONFIG" = "no" ; then
       echo "*** The db_version function could not be found in the DB2 library."
     else
       if test -f conf.db2test ; then
        :
       else
          echo "*** Could not run DB2 test program, checking why..."
          CFLAGS="$CFLAGS $DB2_CFLAGS"
          LIBS="$LIBS $DB2_LIBS"
          AC_TRY_LINK([
#include <stdio.h>
#include <db2/db.h>
],      [ return 0; ],
        [ echo "*** The test program compiled, but did not run. This usually means"
          echo "*** that the run-time linker is not finding DB2 or finding the wrong"
          echo "*** version of DB2. If it is not finding DB2, you'll need to set your"
          echo "*** LD_LIBRARY_PATH environment variable, or edit /etc/ld.so.conf to point"
          echo "*** to the installed location. Also, make sure you have run ldconfig if that"
          echo "*** is required on your system"
          echo "***"
          echo "*** If you have an old version installed, it is best to remove it, although"
          echo "*** you may also be able to get things to work by modifying LD_LIBRARY_PATH"],
        [ echo "*** The test program failed to compile or link. See the file config.log for the"
          echo "*** exact error that occured." ])

          CFLAGS="$ac_save_CFLAGS"
          LIBS="$ac_save_LIBS"
       fi
     fi
     DB2_CFLAGS=""
     DB2_LIBS=""
     ifelse([$3], , :, [$3])
  fi
  AC_SUBST(DB2_CFLAGS)
  AC_SUBST(DB2_LIBS)
  rm -f conf.db2test
])
